@@ -9,7 +9,6 @@ from tableauscraper import utils
 from tableauscraper import api
 from tableauscraper.TableauWorksheet import TableauWorksheet
 from tableauscraper.TableauWorkbook import TableauWorkbook
-from typing import List
 import logging
 
 
@@ -98,7 +97,7 @@ class TableauScraper:
                     self.info)
             self.dashboard = self.info["sheetName"]
             self.filters = utils.getFiltersForAllWorksheet(
-                self.data, self.info, rootDashboard=self.dashboard)
+                self.logger, self.data, self.info, rootDashboard=self.dashboard)
         except (AttributeError):
             raise TableauException(message=r)
 
