@@ -1,4 +1,3 @@
-import pandas as pd
 import copy
 import json
 
@@ -86,19 +85,6 @@ def getWorksheetNames(wb):
         t.name
         for t in wb.worksheets
     ]
-    # if scraper.cmdResponse:
-    #     presModel = scraper._originalData["vqlCmdResponse"]["layoutStatus"]["applicationPresModel"]
-    #     return [
-    #         t["worksheet"]
-    #         for t in listWorksheetCmdResponse(presModel)
-    #     ]
-    # else:
-    #     presModel = getPresModelVizData(scraper._originalData)
-    #     if presModel is None:
-    #         presModel = getPresModelVizInfo(scraper._originalInfo)
-    #         worksheets = listWorksheetInfo(presModel)
-    #         return listStoryPointsInfo(presModel) if len(worksheets) == 0 else worksheets
-    #     return listWorksheet(presModel)
 
 
 def listWorksheet(presModelMap):
@@ -336,7 +322,7 @@ def getDataFullCmdResponse(presModel, originSegments, dataSegments={}):
     return dataFull
 
 
-def getStoryPointsFromInfo(info):
+def getStoryPointsFromInfo(logger, info):
     result = {
         "storyBoard": "",
         "storyPoints": []
@@ -344,7 +330,7 @@ def getStoryPointsFromInfo(info):
     if "sheetName" in info:
         result["storyBoard"] = info["sheetName"]
     else:
-        print("sheet name not found")
+        logger.warning("sheet name not found")
         return result
     presModel = getPresModelVizInfo(info)
     if (("workbookPresModel" in presModel) and
@@ -605,7 +591,7 @@ def getSelectedFilters(presModel, worksheetName):
     return selectedFilters
 
 
-def listFilters(presModel, worksheetName, selectedFilters, rootDashboard):
+def listFilters(logger, presModel, worksheetName, selectedFilters, rootDashboard):
     zones = presModel["workbookPresModel"]["dashboardPresModel"]["zones"]
     filters = [
         json.loads(zones[z]["presModelHolder"]["visual"]["filtersJson"])
@@ -624,7 +610,8 @@ def listFilters(presModel, worksheetName, selectedFilters, rootDashboard):
                 {
                     "columns": [(z["caption"], z["name"], z["ordinal"]) for z in t["table"]["schema"]],
                     "values": [z["t"][0]["v"] for z in t["table"]["tuples"] if "t" in z and len(z["t"]) != 0],
-                    "selection": [z["t"][0]["v"] for z in t["table"]["tuples"] if ("t" in z) and (len(z["t"]) != 0) and ("s" in z) and (z["s"] == True)]
+                    "selection": [z["t"][0]["v"] for z in t["table"]["tuples"] if ("t" in z) and (len(z["t"]) != 0) and ("s" in z) and (z["s"] == True)],
+                    "all": t.get("all", False) or t.get("allChecked", False),
                 }
                 for t in arr
                 if "table" in t
@@ -638,7 +625,7 @@ def listFilters(presModel, worksheetName, selectedFilters, rootDashboard):
                         "ordinal": c[2],
                         "values": r["values"],
                         "globalFieldName": f"[{c[1][0]}].[{c[1][1]}]",
-                        "selection": r["selection"],
+                        "selection": r["selection"] if not r["all"] else r["values"],
                         "selectionAlt": [it for it in selectedFilters if it["fn"] == f"[{c[1][0]}].[{c[1][1]}]"]
                     })
         return entries
@@ -656,10 +643,23 @@ def listFilters(presModel, worksheetName, selectedFilters, rootDashboard):
             keys = list(storypoint.keys())
             filtersList = []
             for key in keys:
-                storyboard = storypoint[key]["dashboardPresModel"]["sheetPath"]["storyboard"]
-                storyboardId = storypoint[key]["dashboardPresModel"]["sheetPath"]["storyPointId"]
-                dashboard = storypoint[key]["dashboardPresModel"]["sheetPath"]["sheetName"] if storypoint[
-                    key]["dashboardPresModel"]["sheetPath"]["isDashboard"] else rootDashboard
+                storyboardId = storypoint[key]["storyPointId"]
+
+                # get storyboard and dashboard values
+                if "sheetPath" in storypoint[key]["dashboardPresModel"]:
+                    storyboard = storypoint[key]["dashboardPresModel"]["sheetPath"]["storyboard"]
+                    dashboard = storypoint[key]["dashboardPresModel"]["sheetPath"]["sheetName"] if storypoint[
+                        key]["dashboardPresModel"]["sheetPath"]["isDashboard"] else rootDashboard
+                elif "visualIds" in storypoint[key]["dashboardPresModel"]:
+                    visualIds = storypoint[key]["dashboardPresModel"]["visualIds"]
+                    if isinstance(visualIds, list):
+                        visualIds = visualIds[0]
+                    storyboard = visualIds["storyboard"]
+                    dashboard = visualIds["dashboard"]
+                else:
+                    logger.warning(
+                        "sheetPath and visualIds not found in dashboardPresModel")
+                    return []
                 zones = storypoint[key]["dashboardPresModel"]["zones"]
                 filters = [
                     json.loads(zones[z]["presModelHolder"]
@@ -679,7 +679,8 @@ def listFilters(presModel, worksheetName, selectedFilters, rootDashboard):
                             {
                                 "columns": [(z["caption"], z["name"], z["ordinal"]) for z in t["table"]["schema"]],
                                 "values": [z["t"][0]["v"] for z in t["table"]["tuples"] if "t" in z and len(z["t"]) != 0],
-                                "selection": [z["t"][0]["v"] for z in t["table"]["tuples"] if ("t" in z) and (len(z["t"]) != 0) and ("s" in z) and (z["s"] == True)]
+                                "selection": [z["t"][0]["v"] for z in t["table"]["tuples"] if ("t" in z) and (len(z["t"]) != 0) and ("s" in z) and (z["s"] == True)],
+                                "all": t.get("all", False) or t.get("allChecked", False),
                             }
                             for t in arr
                             if "table" in t
@@ -693,7 +694,7 @@ def listFilters(presModel, worksheetName, selectedFilters, rootDashboard):
                                     "ordinal": c[2],
                                     "values": r["values"],
                                     "globalFieldName": f"[{c[1][0]}].[{c[1][1]}]",
-                                    "selection": r["selection"],
+                                    "selection": r["selection"] if not r["all"] else r["values"],
                                     "selectionAlt": [it for it in selectedFilters if it["fn"] == f"[{c[1][0]}].[{c[1][1]}]"],
                                     "storyboard": storyboard,
                                     "storyboardId": storyboardId,
@@ -712,17 +713,19 @@ def getTooltipText(tooltipServerCmdResponse):
         return ""
 
 
-def getFiltersForAllWorksheet(data, info, rootDashboard, cmdResponse=False):
+def getFiltersForAllWorksheet(logger, data, info, rootDashboard, cmdResponse=False):
     filterResult = {}
     if cmdResponse:
         presModel = data["vqlCmdResponse"]["layoutStatus"]["applicationPresModel"]
         worksheets = listWorksheetCmdResponse(presModel)
+        if len(worksheets) == 0:
+            worksheets = listStoryPointsCmdResponse(presModel)
         for worksheet in worksheets:
             selectedFilters = getSelectedFilters(
                 presModel,
                 worksheet["worksheet"]
             )
-            filters = listFilters(presModel,
+            filters = listFilters(logger, presModel,
                                   worksheet["worksheet"], selectedFilters, rootDashboard)
             filterResult[worksheet["worksheet"]] = filters
     else:
@@ -739,7 +742,7 @@ def getFiltersForAllWorksheet(data, info, rootDashboard, cmdResponse=False):
         for worksheet in worksheets:
             selectedFilters = getSelectedFilters(
                 presModelMapVizInfo, worksheet)
-            filters = listFilters(presModelMapVizInfo,
+            filters = listFilters(logger, presModelMapVizInfo,
                                   worksheet, selectedFilters, rootDashboard)
             filterResult[worksheet] = filters
     return filterResult
